# tinyrox says don't edit this manually, but it can't stop you!

export(autoresearch)
export(backlinks)
export(dedup)
export(default_vault)
export(ingest)
export(ingest_agent_context)
export(ingest_briefing)
export(ingest_repo)
export(ingest_url)
export(init_vault)
export(lint)
export(log_entry)
export(manifest_path)
export(migrate_briefings_to_repos)
export(outlinks)
export(page_context)
export(pensar_skill_path)
export(read_manifest)
export(recent_activity)
export(related_pages)
export(search_pages)
export(show_page)
export(status)
export(tags)
export(update_index)
export(update_manifest)
export(use_vault)
export(vault_commit)
export(vault_export)
export(vault_graph)
export(vault_registry)

S3method(print,pensar_lint)
S3method(print,pensar_page)
S3method(print,pensar_research)
S3method(print,pensar_status)

importFrom(stats,setNames)
